@@ -39,7 +39,7 @@ class Pool(object):
     """
 
     __slots__ = ('__worker_size', '__loop_count', '__daemon', '__futures',
-                 '__lock', '__is_killed',)
+                 '__lock', '__is_killed', '__worker_finished',)
 
     def __init__(self, worker_size=1, loop_count=sys.maxint, daemon=True):
         """
@@ -80,6 +80,9 @@ class Pool(object):
         self.__lock = threading.Lock()
         self.__is_killed = False
 
+        self.__worker_finished = threading.Event()
+        self.__worker_finished.clear()
+
         for i in xrange(worker_size):
             self.__create_worker()
 
@@ -91,8 +94,11 @@ class Pool(object):
     def __run(self):
         try:
             for i in xrange(self.__loop_count):
-                future = self.__futures.get()
+                future = self.__futures.get(block=True)
                 if future is None:
+                    self.__worker_size -= 1
+                    if self.__worker_size == 0:
+                        self.__worker_finished.set()
                     return
                 future._run()
 
@@ -145,7 +151,7 @@ class Pool(object):
             raise TypeError("The argument 2 'func' is requested to be "
                             "callable.")
 
-        future = _future.Future._create(func, *args, **kwargs)
+        future = _future.Future(func, *args, **kwargs)
         with self.__lock:
             if self.__is_killed:
                 raise error.DeadPoolError("Pool.send is called after killed.")
@@ -153,28 +159,49 @@ class Pool(object):
 
         return future
 
-    def kill(self):
+    def kill(self, force=False, block=False):
         """
-        Set internal flag and send terminate signal to all worker threads.
+        Set internal flag and make workers stop.
 
-        This method returns immediately, however workers will work till the all
-        queued callable are finished. After all callables are finished, workers
-        kill themselves. If `send' is called after this methos is called, it
-        raises DeadPoolError.
+        If the argument force is True, the workers will stop after their
+        current task is finished. In this case, some futures could be left
+        undone, and they will raise DeadPoolError when their receive method
+        is called. On the other hand, if the argument force is False, the
+        workers will stop after all queued tasks are finished. The default is
+        value False.
+
+        If the argument block is True, block until the all workers done the
+        tasks. Otherwise, it returns immediately. The default value is False.
+
+        If `send' is called after this methos is called, it raises
+        DeadPoolError.
 
         If this class is used in with statement, this method is called when the
         block exited. Otherwise, this method must be called after finished
-        using the object.
+        using the object, or the worker threads are left till the program ends.
+        (Or, if the constructor is called with optional argument daemon=False,
+        dead lock occurres and program will never ends.)
 
         This method is thread safe and can be callable many times.
         """
 
         with self.__lock:
-            if self.__is_killed:
-                return
-            self.__is_killed = True
+            if not self.__is_killed:
+                self.__is_killed = True
 
-        [self.__futures.put(None) for i in xrange(self.__worker_size)]
+        if force:
+            while not self.__futures.empty():
+                f = self.__futures.get(block=False)
+                f._is_error = True
+                f._result = error.DeadPoolError("The pool is killed before the"
+                                                " task is done.")
+                f._is_finished.set()
+
+        for i in xrange(self.__worker_size):
+            self.__futures.put(None)
+
+        if block:
+            self.__worker_finished.wait()
 
     def __del__(self):
         self.kill()
